# is_cmyk()

## How to use

1. ```python
   from colorcodetools.cmyk.validate import is_cmyk
   is_cmyk('c/m/y/k')
   ```
2. ```python
   import colorcodetools
   colorcodetools.cmyk.validate.is_cmyk('c/m/y/k')
   ```

## Parameters

1. Required parameters:

   - cmyk:  
      Enter cmyk code which should be inverted.
     - `type: string`
     - `default: None`
     - `example: '100/50/0/45'`

## Return value

- `type: boolean`
